@@ -1,29 +1,29 @@
 from pathlib import Path
 
-__version__ = "1.1.6"
+__version__ = "1.1.7"
 
 DATAFILE = Path(__file__).parent.absolute()/"data/untouchable.dat"
 USERFILE = Path.home()/".python-negar"
 
 INFO="""قابلیت های ویراستار ' نگار  ':
 * جایگزینی
-    + خط تیره های پیاپی نظیر (--) و (---) با معادل های استاندارد شان
-    + سه نقطه ی پیاپی (...) با کاراکتر استانداردش در زبان فارسی
-	+ علایمی نظیر کتیشن فارسی با گیومه ؛  'نگار'
-	+ اعداد عربی '١٢٣٤٥٦٧٨٩٠' و انگلیسی '1234567890'  با معادل فارسی
-	+ کاراکتر های غیر فارسی نظیر ',;%يةك' با معادل های فارسی
+	╛═ خط تیره های پیاپی نظیر (--) و (---) با معادل های استاندارد شان
+	╛═ سه نقطه ی پیاپی (...) با کاراکتر استانداردش در زبان فارسی
+	╛═ علایمی نظیر کتیشن فارسی با گیومه ؛  'نگار'
+	╛═ اعداد عربی '١٢٣٤٥٦٧٨٩٠' و انگلیسی '1234567890'  با معادل فارسی
+	╛═ کاراکتر های غیر فارسی نظیر ',;%يةك' با معادل های فارسی
 
 * تنظیم فاصله
-	+ کلماتی که با 'ی' پسوند همراه هستند مانند 'همه ی ' -- و البته امکان جایگزینی آن با حمزه 'ء' ( در صورت انتخاب کاربر )
-	+ پرانتز ها  یا دیگر علایم ؛ ( نگار )
-	+ علائم نقطه‌گذاری ؛ بدون فاصله از قبل و با یک فاصله از بعد به استثنای اعداد اعشاری مانند 12.4
-	+ در پیشوند کلمات با نیم‌فاصله نظیر ' می شود '، ' میشود '، ' بی شک '، ' بیشک ' , ' خانه اش '، ' وظیفه شناس ' ، ' کمک تان '  و یا ' نمیرود '
-	+ در پسوند کلمات با نیم‌فاصله نظیر کتابها، خوشترین -- و البته امکان عدم تنظیم (در صورت انتخاب کاربر)
+	╛═ کلماتی که با 'ی' پسوند همراه هستند مانند 'همه ی ' -- و البته امکان جایگزینی آن با حمزه 'ء' ( در صورت انتخاب کاربر )
+	╛═ پرانتز ها  یا دیگر علایم ؛ ( نگار )
+	╛═ علائم نقطه‌گذاری ؛ بدون فاصله از قبل و با یک فاصله از بعد به استثنای اعداد اعشاری مانند 12.4
+	╛═ در پیشوند کلمات با نیم‌فاصله نظیر ' می شود '، ' میشود '، ' بی شک '، ' بیشک ' , ' خانه اش '، ' وظیفه شناس ' ، ' کمک تان '  و یا ' نمیرود '
+	╛═ در پسوند کلمات با نیم‌فاصله نظیر کتابها، خوشترین -- و البته امکان عدم تنظیم (در صورت انتخاب کاربر)
 
 * جلوگیری از
-	+ استفاده ی بیش از یک علامت ؟؟؟؟ یا !!!
-	+ کشیـــــــــدگـــــــــــــــــی در کــــــــــــلمــــات
-	+ فضا های         خالی     بیش          از       حد"""
+	╛═ استفاده ی بیش از یک علامت ؟؟؟؟ یا !!!
+	╛═ کشیـــــــــدگـــــــــــــــــی در کــــــــــــلمــــات
+	╛═ فضا های         خالی     بیش          از       حد"""
 
 URLREGX = r"""#https://gist.github.com/gruber/8891611
 \b
