@@ -1,8 +1,11 @@
 def main():
     try:
-        from negar_gui.gui import main
-        main()
+        from negar_gui import gui
+        gui.main()
     except ModuleNotFoundError:
         print("Install `negar-gui` to have a GUI! :D")
         print("==>> pip install negar-gui")
-        print("After installing negar-gui, `negar` would be an alias for `negar-gui`")
\ No newline at end of file
+        print("After installing negar-gui, `negar` would be an alias for `negar-gui`")
+
+if __name__=="__main__":
+    main()
